@@ -21,15 +21,25 @@ engine_manager = EngineManager()
         pd.DataFrame: DataFrame containing the query results.
     """
 async def format_to_df(query_output):
-    if inspect.iscoroutinefunction(query_output.fetchall):
-        rows, columns_name = await asyncio.gather(
-            query_output.fetchall(),
-            query_output.keys()
-        )
-    else:
-        rows = query_output.fetchall()
-        columns_name = query_output.keys()
-    return pd.DataFrame(rows, columns=columns_name)
+    try:
+        # Handle fetchall() for async or sync databases
+        if inspect.iscoroutinefunction(query_output.fetchall):
+            rows = await query_output.fetchall()
+        else:
+            rows = query_output.fetchall()
+
+        # Handle keys() for async or sync databases
+        if inspect.iscoroutinefunction(query_output.keys):
+            columns_name = await query_output.keys()
+        else:
+            columns_name = query_output.keys()
+
+        # Return DataFrame
+        return pd.DataFrame(rows, columns=columns_name)
+
+    except Exception as e:
+        logger.error(f"Error converting query output to DataFrame: {e}")
+        raise
 
 """Executes a SQL query and optionally backs up a specified table.
 
@@ -124,10 +134,8 @@ async def backup_table(table_to_backup , conn):
 
         backup_query = f"SELECT * FROM {table_to_backup}"
         result = await conn.execute(text(backup_query))
-        rows, columns = await asyncio.gather(
-            result.fetchall(),
-            result.keys()
-        )
+        rows = await result.fetchall()
+        columns = await result.keys()
         backup_df = pd.DataFrame(rows, columns=columns)
         backup_filename = os.path.join(backup_dir_name, f"{table_to_backup}_backup_{datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}.md")
 
